pub struct ModuleRequestSet { /* private fields */ }Expand description
A set of requests to generate code for a series of modules
Implementations
Sourceimpl ModuleRequestSet
impl ModuleRequestSet
Sourcepub fn new<I>(
input_protos: I,
proto_file: Vec<FileDescriptorProto>,
raw_request: &[u8],
default_package_filename: Option<&str>,
flat_output_dir: bool,
) -> Result<Self, DecodeError>where
I: IntoIterator<Item = String>,
pub fn new<I>(
input_protos: I,
proto_file: Vec<FileDescriptorProto>,
raw_request: &[u8],
default_package_filename: Option<&str>,
flat_output_dir: bool,
) -> Result<Self, DecodeError>where
I: IntoIterator<Item = String>,
Construct a new module request set from an encoded CodeGeneratorRequest
Sourcepub fn requests(&self) -> impl Iterator<Item = (&Module, &ModuleRequest)>
pub fn requests(&self) -> impl Iterator<Item = (&Module, &ModuleRequest)>
An ordered iterator of all requests
Sourcepub fn for_module(&self, module: &Module) -> Option<&ModuleRequest>
pub fn for_module(&self, module: &Module) -> Option<&ModuleRequest>
Retrieve the request for the given module
pub fn modules(&self) -> impl Iterator<Item = &Module>